/*
 * $Id: WebappXMLResourcesFactory.java 349025 2005-11-25 21:09:54Z niallp $
 * $Revision: 349025 $
 * $Date: 2005-11-25 16:09:54 -0500 (Fri, 25 Nov 2005) $
 *
 * ====================================================================
 *
 *  Copyright 2003-2005 The Apache Software Foundation
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.commons.resources.impl;


import org.apache.commons.resources.Resources;
import org.apache.commons.resources.ResourcesException;

/**
 * <p>Concrete implementation of {@link org.apache.commons.resources.ResourcesFactory} that creates
 * {@link org.apache.commons.resources.Resources} instances that wrap a family (one per Locale) of
 * XML documents that share a base context-relative path for
 * servlet context resources, and have name suffixes reflecting
 * the Locale for which the document's messages apply.  Resources are
 * looked up in a hierarchy of documents in a manner identical to that
 * performed by <code>java.util.ResourceBundle.getBundle()</code>.</p>
 *
 * <p>The configuration variable passed to the <code>createResources()</code>
 * method must be the context-relative base name of the XML document family,
 * and must begin with a slash ('/') character.
 * For example, if the configuration URL is passed as
 * <code>/WEB-INF/resources/MyResources</code>, the resources for the
 * <code>en_US</code> Locale would be stored under context resource
 * <code>/WEB-INF/resources/MyReesources_en_US.xml</code>, and the default
 * resources would be stored in
 * <code>/WEB-INF/resources/MyResources.xml</code>.</p>
 */
public class WebappXMLResourcesFactory extends WebappResourcesFactoryBase {

    /**
     * <p>Create and return a new {@link org.apache.commons.resources.Resources} instance with the
     * specified logical name, after calling its <code>init()</code>
     * method and delegating the relevant properties.</p>
     *
     * @param name Logical name of the {@link org.apache.commons.resources.Resources} instance to create
     * @param config Configuration string for this resource (if any)
     * @return The new Resources instance.
     *
     * @exception ResourcesException if a {@link org.apache.commons.resources.Resources} instance
     *  of the specified logical name cannot be created.
     */
    protected Resources createResources(String name, String config) {

        Resources res =
            new WebappXMLResources(name, config, getServletContext());
        res.setReturnNull(isReturnNull());
        res.init();
        return (res);

    }


}
