/*
 * $Id: IteratorEnumerationTestCase.java 358692 2005-12-23 03:37:26Z niallp $
 * $Revision: 358692 $
 * $Date: 2005-12-22 22:37:26 -0500 (Thu, 22 Dec 2005) $
 *
 * ====================================================================
 *
 *  Copyright 2005 The Apache Software Foundation
 * 
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 *
 */

package org.apache.commons.resources.util;

import junit.framework.Test;
import junit.framework.TestCase;
import junit.framework.TestSuite;
import java.util.ArrayList;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.Enumeration;

/**
 * Unit tests for the <code>org.apache.commons.resources.util.IteratorEnumeration</code> class.
 */
public class IteratorEnumerationTestCase extends TestCase {
    
    /**
     * Defines the testcase name for JUnit.
     *
     * @param theName the testcase's name.
     */
    public IteratorEnumerationTestCase(String theName) {
        super(theName);
    }

    /**
     * Start the tests.
     *
     * @param theArgs the arguments. Not used
     */
    public static void main(String[] theArgs) {
        junit.awtui.TestRunner.main(
            new String[] { IteratorEnumerationTestCase.class.getName()});
    }

    /**
     * @return a test suite (<code>TestSuite</code>) that includes all methods
     *         starting with "test"
     */
    public static Test suite() {
        return new TestSuite(IteratorEnumerationTestCase.class);
    }

    public void testIterator() {

        // Wrap an Iterator
        ArrayList list = new ArrayList();
        list.add("one");
        Enumeration enumeration = new IteratorEnumeration(list.iterator());
        Iterator iterator       = new IteratorEnumeration(list.iterator());

        // Test Enumeration
        assertTrue("Enumeration.hasMoreElements(A)", enumeration.hasMoreElements());
        assertEquals("Enumeration.nextElement", "one", enumeration.nextElement());
        assertFalse("Enumeration.hasMoreElements(B)", enumeration.hasMoreElements());

        // Test Iterator
        assertTrue("Iterator.hasNext(A)", iterator.hasNext());
        assertEquals("Iterator.next",  "one", iterator.next());
        assertFalse("Iterator.hasNext(B)", iterator.hasNext());
        try {
           iterator.remove();
           fail("Expected UnsupportedOperationException");
        } catch(UnsupportedOperationException e) {
           // expected result
        }

    }

    public void testEnumeration() {

        // Wrap an Enumeration
        Hashtable hashtable = new Hashtable();
        hashtable.put("one", "XXX");
        Enumeration enumeration = new IteratorEnumeration(hashtable.keys());
        Iterator iterator       = new IteratorEnumeration(hashtable.keys());

        // Test Enumeration
        assertTrue("Enumeration.hasMoreElements(A)", enumeration.hasMoreElements());
        assertEquals("Enumeration.nextElement", "one", enumeration.nextElement());
        assertFalse("Enumeration.hasMoreElements(B)", enumeration.hasMoreElements());

        // Test Iterator
        assertTrue("Iterator.hasNext(A)", iterator.hasNext());
        assertEquals("Iterator.next",  "one", iterator.next());
        assertFalse("Iterator.hasNext(B)", iterator.hasNext());

        try {
           iterator.remove();
           fail("Expected UnsupportedOperationException");
        } catch(UnsupportedOperationException e) {
           // expected result
        }

        
    }
}